module.exports = function(grunt) {
    var utilPath = 'js/Util/*.js';
    var repositoryPath = 'js/Repository/*.js';
    var servicePath = 'js/Service/*.js';
    var controllerPath = 'js/Controller/*.js';
    var specsPath = 'specs/**/*spec*.js';
    var orderFiles = [];
    var helperPath = 'specs/helpers/*.js';
    var compassPath = '';

    grunt.initConfig({
        compass: {
            dist: {
                options: {
                    force: true,
                    config: 'config.rb',
                    outputStyle: 'compressed'
                }
            }
        },
        concat: {
            none: {},
            zh: {
                options: {
                    process: function(src, filepath) {
                        return '\n' + '// FILE: ' + filepath + '\n' + src;
                    }
                },
                src: ['libs/**/*.js', utilPath, repositoryPath, servicePath, controllerPath],
                dest: 'dist/main.js'
            }
        },
        jshint: {
            all: ['Gruntfile.js', 'lib/**/*.js', specsPath, utilPath, repositoryPath, servicePath, controllerPath]
        },
        jasmine: {
            pivotal: {
                // Your project's source files
                src: [utilPath, repositoryPath, servicePath, controllerPath],
                // Your Jasmine spec files
                options: {
                    vendor: ['bower_components/assets/dist/main.js', '../../projectManagement/frontend/dist/main.js', 'libs/**/*.js', "specs/libs/*.js"],
                    specs: specsPath,
                    // Your spec helper files
                    helpers: helperPath
                }
            }
        },
        uglify: {
            options: {
                mangle: false,
                compress: false,
                report: 'min',
                // the banner is inserted at the top of the output
                banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
            },
            dist: {
                files: {
                    'dist/main.min.js': ['libs/**/*.js', utilPath, repositoryPath, servicePath, controllerPath].concat(orderFiles)
                }
            }
        },
        watch: {
            pivotal: {
                files: [utilPath, repositoryPath, servicePath, controllerPath, specsPath],
                tasks: ['jshint', 'uglify', 'concat', 'jasmine']
            }
        },
        complexity: {
            generic: {
                src: [specsPath, utilPath, repositoryPath, servicePath, controllerPath, compassPath].concat(orderFiles),
                exclude: ['doNotTest.js'],
                options: {
                    breakOnErrors: true,
                    jsLintXML: 'report.xml', // create XML JSLint-like report
                    checkstyleXML: 'checkstyle.xml', // create checkstyle report
                    errorsOnly: false, // show only maintainability errors
                    cyclomatic: [], // or optionally a single value, like 3
                    halstead: [8, 13, 20], // or optionally a single value, like 8
                    maintainability: 100,
                    hideComplexFunctions: false, // only display maintainability
                    broadcast: false // broadcast data over event-bus
                }
            }
        },
        bump: {
            options: {
                files: ['bower.json'],
                updateConfigs: [],
                commit: true,
                commitMessage: 'Release v%VERSION%',
                commitFiles: ['bower.json'],
                createTag: true,
                tagName: '%VERSION%',
                tagMessage: 'Version %VERSION%',
                push: true,
                pushTo: 'origin',
                gitDescribeOptions: '--tags --always --abbrev=1 --dirty=-d',
                globalReplace: false,
                prereleaseName: false,
                metadata: '',
                regExp: false
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-jasmine');
    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-complexity');
    grunt.loadNpmTasks('grunt-bump');

    // Default task.
    grunt.registerTask('default', ['jshint', 'jasmine', 'uglify', 'concat']);
    grunt.registerTask('build', ['jshint', 'jasmine', 'uglify', 'concat']);
    grunt.registerTask('commit', ['jshint', 'uglify', 'concat']);

};